CREATE SCHEMA IBM_TRAM;

----------------------------------------
--TIME_DIMENSION
----------------------------------------

CREATE TABLE IBM_TRAM.TIME_DIMENSION (  
  TIME_RANGE_START TIMESTAMP NOT NULL,  
  TIME_RANGE_END TIMESTAMP NOT NULL, 
  HOUR_KEY TIMESTAMP NOT NULL,  
  DAY_KEY TIMESTAMP NOT NULL,  
  WEEK_KEY TIMESTAMP NOT NULL,  
  MONTH_KEY TIMESTAMP NOT NULL,  
  QUARTER_KEY TIMESTAMP NOT NULL,
  YEAR_KEY TIMESTAMP NOT NULL,  
  CURRENT_DATE DATE NOT NULL,  
  CURRENT_MINUTE SMALLINT,  
  CURRENT_HOUR SMALLINT,  
  CURRENT_DAY SMALLINT,  
  CURRENT_WEEK SMALLINT,  
  CURRENT_MONTH SMALLINT,  
  CURRENT_QUARTER SMALLINT,  
  CURRENT_YEAR SMALLINT, 
  DAY_OF_WEEK SMALLINT,  
  DAYS_IN_MONTH SMALLINT,  
  DAY_OF_YEAR SMALLINT,  
  WEEK_OF_MONTH SMALLINT,  
  WEEK_OF_QUARTER SMALLINT,
  CANDLETIMESTAMP CHAR(16) NOT NULL,  
  END_CANDLETIMESTAMP CHAR(16) NOT NULL,  
  PRIMARY KEY( TIME_RANGE_START, TIME_RANGE_END)
) ;



----------------------------------------
--MONTH LooKUP
----------------------------------------


CREATE TABLE IBM_TRAM.MONTH_LOOKUP(
	MONTH_NUMBER SMALLINT NOT NULL,
	MONTH_EN VARCHAR(12),
	MONTH_FR VARCHAR(25),
	MONTH_PT_BR VARCHAR(25),
	MONTH_JA VARCHAR(25),
	MONTH_DE VARCHAR(25),
	MONTH_IT VARCHAR(25),
	MONTH_KO VARCHAR(25),
	MONTH_CS VARCHAR(25),
	MONTH_HU VARCHAR(25),
	MONTH_PL VARCHAR(25),
	MONTH_RU VARCHAR(25),
	MONTH_ZH_CN VARCHAR(25),
	MONTH_ZH_TW VARCHAR(25),
	MONTH_ES VARCHAR(25),
	PRIMARY KEY (MONTH_NUMBER))
     ;

----------------------------------------
--WEEKDAY LOOKUP
----------------------------------------

CREATE TABLE IBM_TRAM.WEEKDAY_LOOKUP(
	WEEKDAY_NUMBER SMALLINT NOT NULL,
	WEEKDAY_EN VARCHAR(12),
	WEEKDAY_FR VARCHAR(25),
	WEEKDAY_PT_BR VARCHAR(25),
	WEEKDAY_JA VARCHAR(25),
	WEEKDAY_DE VARCHAR(25),
	WEEKDAY_IT VARCHAR(25),
	WEEKDAY_KO VARCHAR(25),
	WEEKDAY_CS VARCHAR(25),
	WEEKDAY_HU VARCHAR(25),
	WEEKDAY_PL VARCHAR(25),
	WEEKDAY_RU VARCHAR(25),
	WEEKDAY_ZH_CN VARCHAR(25),
	WEEKDAY_ZH_TW VARCHAR(25),
	WEEKDAY_ES VARCHAR(25),
	PRIMARY KEY (WEEKDAY_NUMBER))
     ;

----------------------------------------
--Populate MONTH_LOOKUP
----------------------------------------

INSERT into IBM_TRAM.MONTH_LOOKUP
(
	MONTH_NUMBER,
	MONTH_EN,
	MONTH_FR,
	MONTH_PT_BR,
	MONTH_JA,
	MONTH_DE,
	MONTH_IT,
	MONTH_KO,
	MONTH_CS,
	MONTH_HU,
	MONTH_PL,
	MONTH_RU,
	MONTH_ZH_CN,
	MONTH_ZH_TW,
	MONTH_ES	
            )
VALUES (1, 'January', 'January_FR', '', '', '', '', '', '', '', '', '', '','','' ), 
(2, 'February', 'February_FR', '', '', '', '', '', '', '', '', '', '','',''), 
(3, 'March', 'March_FR', '', '', '', '', '', '', '', '', '', '','',''), 
(4, 'April', 'April_FR', '', '', '', '', '', '', '', '', '', '','',''),
(5, 'May', 'May_FR', '', '', '', '', '', '', '', '', '', '','',''), 
(6, 'June', 'June_FR', '', '', '', '', '', '', '', '', '', '','',''), 
(7, 'July', 'July_FR', '', '', '', '', '', '', '', '', '', '','',''),
(8, 'August', 'August_FR', '', '', '', '', '', '', '', '', '', '','',''), 
(9, 'September', 'September_FR', '', '', '', '', '', '', '', '', '', '','',''),
(10, 'October', 'October_FR', '', '', '', '', '', '', '', '', '', '','',''), 
(11, 'November', 'November_FR', '', '', '', '', '', '', '', '', '', '','',''), 
(12, 'December', 'December_FR', '', '', '', '', '', '', '', '', '', '','','');

----------------------------------------
--Populate WEEKDAY_LOOKUP
----------------------------------------

INSERT into IBM_TRAM.WEEKDAY_LOOKUP
(
	WEEKDAY_NUMBER,
	WEEKDAY_EN,
	WEEKDAY_FR,
	WEEKDAY_PT_BR,
	WEEKDAY_JA,
	WEEKDAY_DE,
	WEEKDAY_IT,
	WEEKDAY_KO,
	WEEKDAY_CS,
	WEEKDAY_HU,
	WEEKDAY_PL,
	WEEKDAY_RU,
	WEEKDAY_ZH_CN,
	WEEKDAY_ZH_TW,
	WEEKDAY_ES	
            )
VALUES (1, 'Sunday', 'Sunday_FR', '', '', '', '', '', '', '', '', '', '','','' ), 
(2, 'Monday', 'Monday_FR', '', '', '', '', '', '', '', '', '', '','',''), 
(3, 'Tuesday', 'Tuesday_FR', '', '', '', '', '', '', '', '', '', '','',''), 
(4, 'Wednesday', 'Wednesday_FR', '', '', '', '', '', '', '', '', '', '','',''),
(5, 'Thursday', 'Thursday_FR', '', '', '', '', '', '', '', '', '', '','',''), 
(6, 'Friday', 'Friday_FR', '', '', '', '', '', '', '', '', '', '','',''), 
(7, 'Saturday', 'Saturday_FR', '', '', '', '', '', '', '', '', '', '','','');

----------------------------------------
--Indexes for TIME_DIMENSION
----------------------------------------

CREATE UNIQUE INDEX IBM_TRAM.IXCANDLE     ON IBM_TRAM.TIME_DIMENSION       
(CANDLETIMESTAMP, END_CANDLETIMESTAMP)    
 PCTFREE 20; 

CREATE INDEX IBM_TRAM.IXCURRYRMODAY     ON IBM_TRAM.TIME_DIMENSION      
 (CURRENT_YEAR, CURRENT_MONTH, CURRENT_DAY)  PCTFREE 20; 

CREATE INDEX IBM_TRAM.IXCURRMODAY     ON IBM_TRAM.TIME_DIMENSION       
(CURRENT_MONTH, CURRENT_DAY)  PCTFREE 20 ; 

CREATE INDEX IBM_TRAM.IXCURRMOWK     ON IBM_TRAM.TIME_DIMENSION       
(CURRENT_MONTH, CURRENT_WEEK)  PCTFREE 20 ;
	
CREATE INDEX IBM_TRAM.IXCURRDAYHR     ON IBM_TRAM.TIME_DIMENSION      
 (CURRENT_DAY, CURRENT_HOUR)  PCTFREE 20 ; 

----------------------------------------
--TIMEZONE DIMENSION
----------------------------------------

CREATE TABLE IBM_TRAM.TIMEZONE_DIMENSION (  
  TZOFF INTEGER NOT NULL,
  DLS_START TIMESTAMP,
  DLS_END TIMESTAMP,
  DSLOFF INTEGER,
  NAME_EN VARCHAR(32) NOT NULL,
  "DESC" VARCHAR(128)
) ;



----------------------------------------------
--CDM Classes
----------------------------------------------


-----------------------------------------------
--sys/ComputerSystem
----------------------------------------------

CREATE TABLE IBM_TRAM."ComputerSystem" ( 
CSID  INTEGER  NOT NULL  GENERATED ALWAYS AS IDENTITY (START WITH 1,INCREMENT BY 1, NO CACHE ),
FQDN VARCHAR(64)  , 
"Manufacturer" VARCHAR (64)   , 
"Model" VARCHAR (64)  , 
"SerialNumber" VARCHAR (64)  , 
VMID VARCHAR (128)  , 
"PrimaryMACAddress" VARCHAR (64)  , 
"IpAddress" VARCHAR (32)  ,
"Signature" VARCHAR (128)  ,  
"ManagedSystemName" VARCHAR(64),
"Group" VARCHAR(64),
TIME_RANGE_START TIMESTAMP , 
TIME_RANGE_END TIMESTAMP,
 PRIMARY KEY (CSID)
) ;



commit;
