USE WAREHOUS;

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO


-- clean old version
IF EXISTS (SELECT 1 FROM INFORMATION_SCHEMA.ROUTINES WHERE ROUTINE_NAME = N'generate' AND ROUTINE_TYPE = N'PROCEDURE' AND ROUTINE_SCHEMA = N'ITMUSER')
	DROP PROCEDURE itmuser.generate;
GO


CREATE PROCEDURE itmuser.generate
 @pv_agent varchar(300)
AS
BEGIN
	SET NOCOUNT ON;
    declare @v_resource VARCHAR(200);
    declare @v_domain   VARCHAR(200);
    declare @v_display_name VARCHAR(200);
    declare @v_table VARCHAR(200);

    if ( @pv_agent != 'windows' and  @pv_agent != 'linux' and  @pv_agent != 'unix' )
	begin
	    print N'Unknow agent type: '+@pv_agent;
		return 1;
	end ;
	
	set @v_table = case @pv_agent
			when 'windows' then 'NT_Computer_Information_DV'
			when 'linux' then 'Linux_IP_Address_DV'
			when 'unix' then 'UNIX_IP_Address_DV'
			end;

    if exists (select 1 from INFORMATION_SCHEMA.TABLES where TABLE_NAME = @v_table and upper(TABLE_SCHEMA) = upper('itmuser') )
		begin
            print N'Found table: '+@v_table;
			delete from ManagedSystem where  AgentType= @pv_agent ;
			declare @c_agents CURSOR;
			
			if ( @pv_agent = 'windows' )
				exec sp_executesql N'set @c_agents= cursor for select DISTINCT "System_Name",max( COALESCE("LAT_Computer_Domain_Name", "LAT_Computer_Hostname")) from "itmuser".NT_Computer_Information_DV where COALESCE("LAT_Computer_Domain_Name", "LAT_Computer_Hostname") NOT LIKE ''localhost%'' and COALESCE("LAT_Computer_Domain_Name", "LAT_Computer_Hostname") NOT LIKE ''NO_DNS_ENTRY'' and COALESCE("LAT_Computer_Domain_Name", "LAT_Computer_Hostname") NOT LIKE ''loopback%'' group by "System_Name"; OPEN @c_agents;'
					, N'@c_agents cursor OUTPUT'
					, @c_agents OUTPUT;
			if ( @pv_agent = 'linux' )
				exec sp_executesql N'set @c_agents= cursor for select DISTINCT "System_Name",max("LAT_DNS_Name") from "itmuser".Linux_IP_Address_DV  where "LAT_DNS_Name" NOT LIKE ''localhost%'' and "LAT_DNS_Name" NOT LIKE ''NO_DNS_ENTRY'' and "LAT_DNS_Name" NOT LIKE ''loopback%'' group by "System_Name"; OPEN @c_agents;'
					, N'@c_agents cursor OUTPUT'
					, @c_agents OUTPUT;
			if ( @pv_agent = 'unix' )
				exec sp_executesql N'set @c_agents= cursor for select DISTINCT "System_Name",max("LAT_DNS_Name") from "itmuser".UNIX_IP_Address_DV  where "LAT_DNS_Name" NOT LIKE ''localhost%'' and "LAT_DNS_Name" NOT LIKE ''NO_DNS_ENTRY'' and "LAT_DNS_Name" NOT LIKE ''loopback%'' group by "System_Name"; OPEN @c_agents;'
					, N'@c_agents cursor OUTPUT'
					, @c_agents OUTPUT;
			
                
			fetch NEXT from @c_agents INTO @v_resource, @v_domain;

			while @@FETCH_STATUS = 0
				begin
					set @v_display_name = lower( REPLACE
								               (REPLACE
									               (REPLACE
											            (REPLACE(@v_resource, ':KUX',''),
													'Primary:',''),
												':NT', ''),
											':LZ','')
                                    );
					INSERT INTO ManagedSystem (ManagedSystemName, FullyQualifiedHostname, DisplayName, AgentType) values (
                         @v_resource,
                         @v_domain,
                         @v_display_name,
                         @pv_agent
					);
					fetch NEXT from @c_agents INTO @v_resource, @v_domain;
				end

            close @c_agents;
			deallocate @c_agents;
	    end;
    else
        print N'!There is no ' + convert(varchar,@pv_agent) + N' agent';
    
END;
GO
