CREATE OR REPLACE 
PROCEDURE populate_osagents (
pv_username   varchar2 DEFAULT 'ITMUSER',
pv_win_table  varchar2 DEFAULT 'NT_Computer_Information_DV',
pv_win_system varchar2 DEFAULT 'System_Name',
pv_win_domain varchar2 DEFAULT 'LAT_Computer_Domain_Name',
pv_win_host   varchar2 DEFAULT 'LAT_Computer_Hostname',
pv_unx_table  varchar2 DEFAULT 'UNIX_IP_Address_DV',
pv_unx_system varchar2 DEFAULT 'System_Name',
pv_unx_domain varchar2 DEFAULT 'LAT_DNS_Name',
pv_unx_host   varchar2 DEFAULT 'LAT_DNS_Name',
pv_lin_table  varchar2 DEFAULT 'Linux_IP_Address_DV',
pv_lin_system varchar2 DEFAULT 'System_Name',
pv_lin_domain varchar2 DEFAULT 'LAT_DNS_Name',
pv_lin_host   varchar2 DEFAULT 'LAT_DNS_Name'
)
is
-- cursor for dynamic sql
TYPE cur_type IS REF CURSOR;
servers cur_type;

-- inner procedure
procedure generate(
    pv_table varchar2,
    pv_system varchar2,
    pv_domain varchar2,
    pv_host varchar2,
    pv_agent varchar2
) is
    -- table counter
    v_count_tables NUMBER := 0 ;
    -- placeholder
    v_resource VARCHAR2 (200);
    v_domain   VARCHAR2 (200);
    v_display_name VARCHAR2 (200);
    v_query    VARCHAR2(1000);
begin
    select count(*)
      into v_count_tables
      from All_OBJECTS
     where OBJECT_NAME like pv_table
       and owner like pv_username;

     if v_count_tables = 0 then
       dbms_output.put_line('!There is no ' || pv_agent ||' agent');
     end if;     

    select count(*)
      into v_count_tables
      from All_OBJECTS
     where OBJECT_NAME like pv_table
       and owner like pv_username
       and status like 'VALID' ;

     if v_count_tables = 0 then
       dbms_output.put_line('!View ' || pv_table || ' used for '  || pv_agent ||' agent is not valid. Compile view and re-run script.');
       return;
     else
         -- query construction
         v_query := 'SELECT DISTINCT "'
            || pv_system
            || '",MAX( COALESCE( "'
            || pv_domain 
	    || '", "'
            || pv_host			
            || '") ) FROM '
            || upper(pv_username)
            || '."'
            || pv_table
            || '" WHERE COALESCE( "'
            || pv_domain
	    || '", "'
            || pv_host	
            || '" ) NOT LIKE ''localhost%'' AND COALESCE( "'
            || pv_domain  
	    || '", "'
            || pv_host				
            || '" ) NOT LIKE ''loopback%'' AND COALESCE( "'
            || pv_domain 	
	    || '", "'
            || pv_host				
            || '" ) NOT LIKE ''NO_DNS_ENTRY'''             
            || ' GROUP BY "'
            || pv_system
            || '"'
            ;

         dbms_output.put_line('Found table. Query ['|| pv_agent||']: '|| v_query);
         
         delete from ManagedSystem where AgentType = pv_agent;

         OPEN servers FOR v_query;
         LOOP
             FETCH servers INTO v_resource, v_domain;
                EXIT WHEN servers%NOTFOUND;
                v_display_name := lower( REPLACE
                                        (REPLACE
                                            (REPLACE
                                                (REPLACE(v_resource, ':KUX',''),
                                            'Primary:',''),
                                         ':NT', ''),
                                      ':LZ','')
                                    );
                INSERT INTO ManagedSystem (ManagedSystemName, FullyQualifiedHostname, DisplayName, AgentType) values (
                         v_resource,
                         v_domain,
                         v_display_name,
                         pv_agent
                 );

                dbms_output.put_line('Added ' || v_resource );
            END LOOP;
        CLOSE servers;
        select count (*) into v_count_tables from ManagedSystem where  AgentType like  pv_agent ;
        dbms_output.put_line('Summary ['|| pv_agent||']: ' || v_count_tables );
    end if;


end;
BEGIN
-----------------------------------------------------------------
-- NT
   generate(pv_win_table, pv_win_system, pv_win_domain, pv_win_host, 'windows' );
-----------------------------------------------------------------
-- Unix
   generate(pv_unx_table, pv_unx_system , pv_unx_domain , pv_unx_host, 'unix' );
-----------------------------------------------------------------
-- Linux
   generate(pv_lin_table, pv_lin_system, pv_lin_domain, pv_lin_host, 'linux' );
-----------------------------------------------------------------
   commit;
END;
/




