define def_tbsp =&1

----------------------------------------
--TIME_DIMENSION
----------------------------------------

prompt Adding TIME_DIMENSION
CREATE TABLE TIME_DIMENSION (
  TIME_RANGE_START TIMESTAMP NOT NULL,  
  TIME_RANGE_END TIMESTAMP NOT NULL, 
	HOUR_KEY TIMESTAMP NOT NULL,
	DAY_KEY TIMESTAMP NOT NULL,
	WEEK_KEY TIMESTAMP NOT NULL,
	MONTH_KEY TIMESTAMP NOT NULL,
	QUARTER_KEY TIMESTAMP NOT NULL,
	YEAR_KEY TIMESTAMP NOT NULL,
	CURRENT_DATE DATE NOT NULL,
	CURRENT_MINUTE SMALLINT,	
	CURRENT_HOUR SMALLINT,
	CURRENT_DAY SMALLINT,
	CURRENT_WEEK SMALLINT,
	CURRENT_MONTH SMALLINT,
	CURRENT_QUARTER SMALLINT,
	CURRENT_YEAR SMALLINT,
	DAY_OF_WEEK SMALLINT,
	DAYS_IN_MONTH SMALLINT,
	DAY_OF_YEAR SMALLINT,
	WEEK_OF_MONTH SMALLINT,
	WEEK_OF_QUARTER SMALLINT,
	CANDLETIMESTAMP CHAR(16) NOT NULL,
	END_CANDLETIMESTAMP CHAR(16) NOT NULL,	
      PRIMARY KEY(TIME_RANGE_START, TIME_RANGE_END)         
) TABLESPACE &def_tbsp;

----------------------------------------
--MONTH_LOOKUP
----------------------------------------

prompt Adding MONTH_LOOKUP
CREATE TABLE MONTH_LOOKUP	(
	MONTH_NUMBER SMALLINT,
	MONTH_EN VARCHAR(12),
	MONTH_FR VARCHAR(25),
	MONTH_PT_BR VARCHAR(25),
	MONTH_JA VARCHAR(25),
	MONTH_DE VARCHAR(25),
	MONTH_IT VARCHAR(25),
	MONTH_KO VARCHAR(25),
	MONTH_CS VARCHAR(25),
	MONTH_HU VARCHAR(25),
	MONTH_PL VARCHAR(25),
	MONTH_RU VARCHAR(25),
	MONTH_ZH_CN VARCHAR(25),
	MONTH_ZH_TW VARCHAR(25),
	MONTH_ES VARCHAR(25),
  PRIMARY KEY (MONTH_NUMBER)
) TABLESPACE &def_tbsp;

----------------------------------------
--WEEKDAY_LOOKUP
----------------------------------------

prompt Adding WEEKDAY_LOOKUP
CREATE TABLE WEEKDAY_LOOKUP	(
	WEEKDAY_NUMBER SMALLINT,
	WEEKDAY_EN VARCHAR(12),
	WEEKDAY_FR VARCHAR(25),
	WEEKDAY_PT_BR VARCHAR(25),
	WEEKDAY_JA VARCHAR(25),
	WEEKDAY_DE VARCHAR(25),
	WEEKDAY_IT VARCHAR(25),
	WEEKDAY_KO VARCHAR(25),
	WEEKDAY_CS VARCHAR(25),
	WEEKDAY_HU VARCHAR(25),
	WEEKDAY_PL VARCHAR(25),
	WEEKDAY_RU VARCHAR(25),
	WEEKDAY_ZH_CN VARCHAR(25),
	WEEKDAY_ZH_TW VARCHAR(25),
	WEEKDAY_ES VARCHAR(25),
  PRIMARY KEY (WEEKDAY_NUMBER)
) TABLESPACE &def_tbsp;
----------------------------------------
--CDM Classes
----------------------------------------
--sys/ComputerSystem
----------------------------------------

CREATE TABLE "ComputerSystem"(
  "CSID" INTEGER,
  "FQDN"  VARCHAR (64) ,
  "Manufacturer" VARCHAR (64)  ,
  "Model" VARCHAR (64)  ,
  "SerialNumber" VARCHAR (64)  ,
  "VMID" VARCHAR(128),
  "PrimaryMACAddress" VARCHAR(64),
  "IpAddress" VARCHAR(32),
  "Signature" VARCHAR (128)  ,  
  "ManagedSystemName" VARCHAR(64),
  "Group" VARCHAR(64),
  TIME_RANGE_START TIMESTAMP , 
  TIME_RANGE_END TIMESTAMP,
  PRIMARY KEY (CSID)
) TABLESPACE &def_tbsp;


CREATE SEQUENCE IBM_TRAM.SEQ_COMPUTERSYSTEM
 START WITH  1
 INCREMENT BY  1
 NOMINVALUE
 NOMAXVALUE
 NOCACHE 
 ORDER
 ; 

CREATE OR REPLACE TRIGGER pre_insert
 BEFORE
  INSERT
 ON "ComputerSystem"
REFERENCING NEW AS NEW OLD AS OLD
 FOR EACH ROW
declare 
   v_int integer;
begin
    select IBM_TRAM.SEQ_COMPUTERSYSTEM.NEXTVAL
      into v_int 
      from dual;
      :NEW."CSID" := v_int;
end;
/
----------------------------------------
--TIMEZONE DIMENSION
----------------------------------------
CREATE TABLE TIMEZONE_DIMENSION (  
  TZOFF INTEGER NOT NULL,
  DLS_START TIMESTAMP,
  DLS_END TIMESTAMP,
  DSLOFF INTEGER,
  NAME_EN VARCHAR(32) NOT NULL,
  "DESC" VARCHAR(128)
) TABLESPACE &def_tbsp;


CREATE UNIQUE INDEX IXCANDLE ON TIME_DIMENSION       
(CANDLETIMESTAMP, END_CANDLETIMESTAMP)    
 PCTFREE 20; 

CREATE INDEX IXCURRYRMODAY ON TIME_DIMENSION      
 (CURRENT_YEAR, CURRENT_MONTH, CURRENT_DAY)  PCTFREE 20; 

CREATE INDEX IXCURRMODAY ON TIME_DIMENSION       
(CURRENT_MONTH, CURRENT_DAY)  PCTFREE 20 ; 

CREATE INDEX IXCURRMOWK ON TIME_DIMENSION       
(CURRENT_MONTH, CURRENT_WEEK)  PCTFREE 20 ;
	
CREATE INDEX IXCURRDAYHR ON TIME_DIMENSION      
 (CURRENT_DAY, CURRENT_HOUR)  PCTFREE 20 ; 
